@@ -18,7 +18,7 @@
 #   You should have received a copy of the GNU General Public
 #   License along with this library; see the file COPYING.LIB.
 #   If not, write to the Free Software Foundation,
-#   59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+#   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 
 case "$1" in
     # Intel processors are made equivalent
@@ -31,6 +31,11 @@ case "$1" in
 	echo alpha
 	exit 0
 	;;
+    # Make all hppa variants the same
+    hppa*)
+        echo hppa
+        exit 0
+        ;;
     *)
 	echo $1
         exit 0
